@@ -1,7 +1,7 @@
 from django.conf import settings
 from django.http import Http404
 
-from models import Error
+from djangodblog.models import Error
 
 __all__ = ('DBLogMiddleware',)
 
@@ -10,4 +10,8 @@ class DBLogMiddleware(object):
         if not getattr(settings, 'DBLOG_CATCH_404_ERRORS', False) and isinstance(exception, Http404):
             return
 
-        Error.objects.create_from_exception(exception, url=request.build_absolute_uri())
\ No newline at end of file
+        Error.objects.create_from_exception(exception, url=request.build_absolute_uri(), data=dict(
+            META=request.META,
+            POST=request.POST,
+            GET=request.GET,
+        ))
\ No newline at end of file
