@@ -1,6 +1,7 @@
 from django.db import models
 from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
+from django.template.defaultfilters import urlizetrunc
 
 try:
     from idmapper.models import SharedMemoryModel as Model
@@ -9,33 +10,34 @@ except ImportError:
 
 import datetime
 
-from manager import DBLogManager
+from djangodblog.manager import DBLogManager
+from djangodblog.utils import JSONDictField
 
 __all__ = ('Error', 'ErrorBatch')
 
 import logging
 
 LOG_LEVELS = (
-    ('Info', logging.INFO),
-    ('Warning', logging.WARNING),
-    ('Debug', logging.DEBUG),
-    ('Error', logging.ERROR),
-    ('Fatal', logging.FATAL),
+    (logging.INFO, 'Info'),
+    (logging.WARNING, 'Warning'),
+    (logging.DEBUG, 'Debug'),
+    (logging.ERROR, 'Error'),
+    (logging.FATAL, 'Fatal'),
 )
 
 STATUS_LEVELS = (
-    ('Unresolved', 0),
-    ('Resolved', 1),
+    (0, 'Unresolved'),
+    (1, 'Resolved'),
 )
 
 class ErrorBatch(Model):
     logger          = models.CharField(max_length=64, blank=True, default='root', db_index=True)
-    class_name      = models.CharField(_('type'), max_length=128, blank=True, null=True)
+    class_name      = models.CharField(_('type'), max_length=128, blank=True, null=True, db_index=True)
     level           = models.PositiveIntegerField(choices=LOG_LEVELS, default=logging.ERROR, blank=True, db_index=True)
     message         = models.TextField()
     traceback       = models.TextField(blank=True, null=True)
     # XXX: We're using the legacy column for `is_resolved` for status
-    status          = models.PositiveIntegerField(default=0, db_column="is_resolved")
+    status          = models.PositiveIntegerField(default=0, db_column="is_resolved", choices=STATUS_LEVELS)
     times_seen      = models.PositiveIntegerField(default=1)
     last_seen       = models.DateTimeField(default=datetime.datetime.now)
     first_seen      = models.DateTimeField(default=datetime.datetime.now)
@@ -46,23 +48,46 @@ class ErrorBatch(Model):
     objects         = DBLogManager()
 
     class Meta:
-        unique_together = (('logger', 'class_name', 'server_name', 'checksum'),)
-        verbose_name_plural = 'Error batches'
+        unique_together = (('logger', 'server_name', 'checksum'),)
+        verbose_name_plural = 'Error summaries'
+        verbose_name = 'Error summary'
     
     def __unicode__(self):
-        return "(%s) %s: %s" % (self.times_seen, self.class_name, self.message)
+        return "(%s) %s: %s" % (self.times_seen, self.class_name, self.error())
+    
+    def shortened_url(self):
+        url = self.url
+        if len(url) > 60:
+            url = url[:60] + '...'
+        return url
+    shortened_url.short_description = "URL"
+    shortened_url.admin_order_field = 'url'
+
+    def error(self):
+        message = self.message
+        if len(message) > 100:
+            message = message[:97] + '...'
+        return "%s: %s" % (self.class_name, message)
+    error.short_description = 'Error'
+
+    def get_absolute_url(self):
+        return self.url
 
 class Error(Model):
     logger          = models.CharField(max_length=64, blank=True, default='root', db_index=True)
     class_name      = models.CharField(_('type'), max_length=128, blank=True, null=True)
-    level           = models.PositiveIntegerField(choices=LOG_LEVELS, default=logging.FATAL, blank=True, db_index=True)
+    level           = models.PositiveIntegerField(choices=LOG_LEVELS, default=logging.ERROR, blank=True, db_index=True)
     message         = models.TextField()
     traceback       = models.TextField(blank=True, null=True)
     datetime        = models.DateTimeField(default=datetime.datetime.now)
     url             = models.URLField(verify_exists=False, null=True, blank=True)
+    data            = JSONDictField(blank=True, null=True)
     server_name     = models.CharField(max_length=128, db_index=True)
 
     objects         = DBLogManager()
 
     def __unicode__(self):
-        return "%s: %s" % (self.class_name, self.message)
\ No newline at end of file
+        return "%s: %s" % (self.class_name, self.message)
+
+    def get_absolute_url(self):
+        return self.url
\ No newline at end of file
